/*********************************************************************

 Author        : ADI - Apps            www.analog.com/MicroConverter

 Date          : Dec. 2006

 File          : UART2.c

 Hardware      : Applicable to ADuC703x

 Description   : Read part of memory and output through UART.
				 This code demonstrates the use of the fractional divider.
				 The baudrate is calculated with the following formula:
				 	Baudrate = 20480000 / ( 2^CD * 16 * 2 * DL )
 					CD = 1 in this example

				Baudrate = 115200bps		   
 		
*********************************************************************/
#include <ADuC7033.h>

void senddata(short);
void delay(int);
char hex2ascii(char);

int main (void)  {
static unsigned short SOMEDATA[1024];
int i;

	GP2DAT = 0x02000000;		// Enable P2.1 (GPIO8) as an output
	GP1CON = 0x011;

  	COMCON0 = 0x80;				// Setting DLAB
	COMDIV0 = 0x02;				// 115200 bps
   	COMDIV1 = 0x00;
   	COMCON0 = 0x07;				// Clearing DLAB
  	COMDIV2 = 0x8B1C;
	COMCON1 = 0x80;

	for (i=0; i <1024; i++){
		SOMEDATA[i]=i;
	}	
	
	while(1) {
		for (i=0; i <1024; i++)	{
			senddata (SOMEDATA[i]);
		}
		GP2DAT ^=0x020000;		// Complement P2.1
		delay(2000);
	}
}


void delay (int length){
	while (length >=0)
    	length--;
}

void senddata(short to_send){
	while(!(0x020==(COMSTA0 & 0x020))){}
		COMTX = 0x0A;						// output LF 
	while(!(0x020==(COMSTA0 & 0x020))){}
		COMTX = 0x0D;						// output CR 
	while(!(0x020==(COMSTA0 & 0x020))){}
		COMTX = hex2ascii ((to_send >> 8) & 0x0F);
	while(!(0x020==(COMSTA0 & 0x020))){}
		COMTX = hex2ascii ((to_send >> 4) & 0x0F);						
	while(!(0x020==(COMSTA0 & 0x020))){}
		COMTX = hex2ascii (to_send & 0x0F);							
}


char hex2ascii(char toconv){
	if (toconv<0x0A){
		toconv += 0x30;
	}
	else{
		toconv += 0x37;
	}
	return (toconv);
}

